@@ -33,6 +33,10 @@ type PerformanceQuery interface {
 	IsVistaOrNewer() bool
 }
 
+type PerformanceQueryCreator interface {
+	NewPerformanceQuery(string) PerformanceQuery
+}
+
 // PdhError represents error returned from Performance Counters API
 type PdhError struct {
 	ErrorCode uint32
@@ -55,6 +59,13 @@ type PerformanceQueryImpl struct {
 	query PDH_HQUERY
 }
 
+type PerformanceQueryCreatorImpl struct {
+}
+
+func (m PerformanceQueryCreatorImpl) NewPerformanceQuery(string) PerformanceQuery {
+	return &PerformanceQueryImpl{}
+}
+
 // Open creates a new counterPath that is used to manage the collection of performance data.
 // It returns counterPath handle used for subsequent calls for adding counters and querying data
 func (m *PerformanceQueryImpl) Open() error {
@@ -118,7 +129,7 @@ func (m *PerformanceQueryImpl) GetCounterPath(counterHandle PDH_HCOUNTER) (strin
 		buff = make([]byte, bufSize)
 		bufSize = uint32(len(buff))
 		if ret = PdhGetCounterInfo(counterHandle, 0, &bufSize, &buff[0]); ret == ERROR_SUCCESS {
-			ci := (*PDH_COUNTER_INFO)(unsafe.Pointer(&buff[0]))
+			ci := (*PDH_COUNTER_INFO)(unsafe.Pointer(&buff[0])) //nolint:gosec // G103: Valid use of unsafe call to create PDH_COUNTER_INFO
 			return UTF16PtrToString(ci.SzFullPath), nil
 		}
 	}
@@ -169,6 +180,7 @@ func (m *PerformanceQueryImpl) GetFormattedCounterArrayDouble(hCounter PDH_HCOUN
 		buff := make([]byte, buffSize)
 
 		if ret = PdhGetFormattedCounterArrayDouble(hCounter, &buffSize, &itemCount, &buff[0]); ret == ERROR_SUCCESS {
+			//nolint:gosec // G103: Valid use of unsafe call to create PDH_FMT_COUNTERVALUE_ITEM_DOUBLE
 			items := (*[1 << 20]PDH_FMT_COUNTERVALUE_ITEM_DOUBLE)(unsafe.Pointer(&buff[0]))[:itemCount]
 			values := make([]CounterValue, 0, itemCount)
 			for _, item := range items {
@@ -192,6 +204,7 @@ func (m *PerformanceQueryImpl) GetRawCounterArray(hCounter PDH_HCOUNTER) ([]Coun
 		buff := make([]byte, buffSize)
 
 		if ret = PdhGetRawCounterArray(hCounter, &buffSize, &itemCount, &buff[0]); ret == ERROR_SUCCESS {
+			//nolint:gosec // G103: Valid use of unsafe call to create PDH_RAW_COUNTER_ITEM
 			items := (*[1 << 20]PDH_RAW_COUNTER_ITEM)(unsafe.Pointer(&buff[0]))[:itemCount]
 			values := make([]CounterValue, 0, itemCount)
 			for _, item := range items {
@@ -259,6 +272,7 @@ func UTF16PtrToString(s *uint16) string {
 	if s == nil {
 		return ""
 	}
+	//nolint:gosec // G103: Valid use of unsafe call to create string from Windows API LPTSTR (pointer to string)
 	return syscall.UTF16ToString((*[1 << 29]uint16)(unsafe.Pointer(s))[0:])
 }
 
