@@ -98,7 +98,47 @@ func TestGraphiteOK(t *testing.T) {
 	require.NoError(t, err3)
 	t.Log("Finished writing third data")
 	wg2.Wait()
-	g.Close()
+	err := g.Close()
+	require.NoError(t, err)
+}
+
+func TestGraphiteStrictRegex(t *testing.T) {
+	var wg sync.WaitGroup
+	wg.Add(1)
+	t.Log("Starting server")
+	tcpServer, err := net.Listen("tcp", "127.0.0.1:12042")
+	require.NoError(t, err)
+	go func() {
+		defer wg.Done()
+		conn, _ := (tcpServer).Accept()
+		reader := bufio.NewReader(conn)
+		tp := textproto.NewReader(reader)
+		data1, _ := tp.ReadLine()
+		require.Equal(t, "192_168_0_1.|us-west-2|.mymeasurement.myfield 0.123 1289430000", data1)
+		require.NoError(t, conn.Close())
+		require.NoError(t, tcpServer.Close())
+	}()
+
+	m := metric.New(
+		"mymeasurement",
+		map[string]string{
+			"host":       "192.168.0.1",
+			"datacenter": "|us-west-2|",
+		},
+		map[string]interface{}{"myfield": float64(0.123)},
+		time.Date(2010, time.November, 10, 23, 0, 0, 0, time.UTC),
+	)
+
+	g := Graphite{
+		Servers:             []string{"localhost:12042"},
+		Log:                 testutil.Logger{},
+		GraphiteStrictRegex: `[^a-zA-Z0-9-:._=|\p{L}]`,
+	}
+	require.NoError(t, g.Connect())
+	require.NoError(t, g.Write([]telegraf.Metric{m}))
+
+	wg.Wait()
+	require.NoError(t, g.Close())
 }
 
 func TestGraphiteOkWithSeparatorDot(t *testing.T) {
@@ -160,7 +200,8 @@ func TestGraphiteOkWithSeparatorDot(t *testing.T) {
 	require.NoError(t, err3)
 	t.Log("Finished writing third data")
 	wg2.Wait()
-	g.Close()
+	err := g.Close()
+	require.NoError(t, err)
 }
 
 func TestGraphiteOkWithSeparatorUnderscore(t *testing.T) {
@@ -222,7 +263,8 @@ func TestGraphiteOkWithSeparatorUnderscore(t *testing.T) {
 	require.NoError(t, err3)
 	t.Log("Finished writing third data")
 	wg2.Wait()
-	g.Close()
+	err := g.Close()
+	require.NoError(t, err)
 }
 
 func TestGraphiteOKWithMultipleTemplates(t *testing.T) {
@@ -288,7 +330,8 @@ func TestGraphiteOKWithMultipleTemplates(t *testing.T) {
 	require.NoError(t, err3)
 	t.Log("Finished writing third data")
 	wg2.Wait()
-	g.Close()
+	err := g.Close()
+	require.NoError(t, err)
 }
 
 func TestGraphiteOkWithTags(t *testing.T) {
@@ -350,7 +393,8 @@ func TestGraphiteOkWithTags(t *testing.T) {
 	require.NoError(t, err3)
 	t.Log("Finished writing third data")
 	wg2.Wait()
-	g.Close()
+	err := g.Close()
+	require.NoError(t, err)
 }
 
 func TestGraphiteOkWithTagsAndSeparatorDot(t *testing.T) {
@@ -413,7 +457,8 @@ func TestGraphiteOkWithTagsAndSeparatorDot(t *testing.T) {
 	require.NoError(t, err3)
 	t.Log("Finished writing third data")
 	wg2.Wait()
-	g.Close()
+	err := g.Close()
+	require.NoError(t, err)
 }
 
 func TestGraphiteOkWithTagsAndSeparatorUnderscore(t *testing.T) {
@@ -476,7 +521,8 @@ func TestGraphiteOkWithTagsAndSeparatorUnderscore(t *testing.T) {
 	require.NoError(t, err3)
 	t.Log("Finished writing third data")
 	wg2.Wait()
-	g.Close()
+	err := g.Close()
+	require.NoError(t, err)
 }
 
 func TCPServer1(t *testing.T, wg *sync.WaitGroup) {
@@ -495,7 +541,8 @@ func TCPServer1(t *testing.T, wg *sync.WaitGroup) {
 }
 
 func TCPServer2(t *testing.T, wg *sync.WaitGroup) {
-	tcpServer, _ := net.Listen("tcp", "127.0.0.1:12003")
+	tcpServer, err := net.Listen("tcp", "127.0.0.1:12003")
+	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
 		conn2, _ := (tcpServer).Accept()
@@ -511,7 +558,8 @@ func TCPServer2(t *testing.T, wg *sync.WaitGroup) {
 }
 
 func TCPServer1WithMultipleTemplates(t *testing.T, wg *sync.WaitGroup) {
-	tcpServer, _ := net.Listen("tcp", "127.0.0.1:12003")
+	tcpServer, err := net.Listen("tcp", "127.0.0.1:12003")
+	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
 		conn, _ := (tcpServer).Accept()
@@ -525,7 +573,8 @@ func TCPServer1WithMultipleTemplates(t *testing.T, wg *sync.WaitGroup) {
 }
 
 func TCPServer2WithMultipleTemplates(t *testing.T, wg *sync.WaitGroup) {
-	tcpServer, _ := net.Listen("tcp", "127.0.0.1:12003")
+	tcpServer, err := net.Listen("tcp", "127.0.0.1:12003")
+	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
 		conn2, _ := (tcpServer).Accept()
@@ -541,7 +590,8 @@ func TCPServer2WithMultipleTemplates(t *testing.T, wg *sync.WaitGroup) {
 }
 
 func TCPServer1WithTags(t *testing.T, wg *sync.WaitGroup) {
-	tcpServer, _ := net.Listen("tcp", "127.0.0.1:12003")
+	tcpServer, err := net.Listen("tcp", "127.0.0.1:12003")
+	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
 		conn, _ := (tcpServer).Accept()
@@ -555,7 +605,8 @@ func TCPServer1WithTags(t *testing.T, wg *sync.WaitGroup) {
 }
 
 func TCPServer2WithTags(t *testing.T, wg *sync.WaitGroup) {
-	tcpServer, _ := net.Listen("tcp", "127.0.0.1:12003")
+	tcpServer, err := net.Listen("tcp", "127.0.0.1:12003")
+	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
 		conn2, _ := (tcpServer).Accept()
@@ -571,7 +622,8 @@ func TCPServer2WithTags(t *testing.T, wg *sync.WaitGroup) {
 }
 
 func TCPServer1WithTagsSeparatorUnderscore(t *testing.T, wg *sync.WaitGroup) {
-	tcpServer, _ := net.Listen("tcp", "127.0.0.1:12003")
+	tcpServer, err := net.Listen("tcp", "127.0.0.1:12003")
+	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
 		conn, _ := (tcpServer).Accept()
@@ -585,7 +637,8 @@ func TCPServer1WithTagsSeparatorUnderscore(t *testing.T, wg *sync.WaitGroup) {
 }
 
 func TCPServer2WithTagsSeparatorUnderscore(t *testing.T, wg *sync.WaitGroup) {
-	tcpServer, _ := net.Listen("tcp", "127.0.0.1:12003")
+	tcpServer, err := net.Listen("tcp", "127.0.0.1:12003")
+	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
 		conn2, _ := (tcpServer).Accept()
